-- Adminer 3.0.0-dev MySQL dump

SET NAMES utf8;
SET foreign_key_checks = 0;
SET time_zone = 'SYSTEM';
SET sql_mode = 'NO_AUTO_VALUE_ON_ZERO';

DROP DATABASE IF EXISTS `php1001`;
CREATE DATABASE `php1001` /*!40100 DEFAULT CHARACTER SET utf8 COLLATE utf8_czech_ci */;
USE `php1001`;

CREATE TABLE `article` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `url` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `title` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `id_category` int(11) NOT NULL,
  `issued` datetime NOT NULL,
  `modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE KEY `url` (`url`),
  KEY `id_category` (`id_category`),
  CONSTRAINT `article_ibfk_1` FOREIGN KEY (`id_category`) REFERENCES `category` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `article` (`id`, `url`, `title`, `id_category`, `issued`, `modified`) VALUES
(1,	'1001-tipu-triku-php',	'1001 tipů a triků pro PHP',	1,	'2010-06-03 15:59:05',	'2010-06-07 21:53:13');

CREATE TABLE `article_part` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `id_article` int(11) NOT NULL,
  `rank` tinyint(3) unsigned NOT NULL,
  `id_poll` int(11) DEFAULT NULL,
  `story` text COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`),
  KEY `id_poll` (`id_poll`),
  KEY `id_article` (`id_article`,`rank`),
  CONSTRAINT `article_part_ibfk_1` FOREIGN KEY (`id_article`) REFERENCES `article` (`id`),
  CONSTRAINT `article_part_ibfk_2` FOREIGN KEY (`id_poll`) REFERENCES `poll` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `article_part` (`id`, `id_article`, `rank`, `id_poll`, `story`) VALUES
(1,	1,	1,	NULL,	'1001 tipů a triků pro PHP');

CREATE TABLE `article_tag` (
  `id_article` int(11) NOT NULL,
  `id_tag` int(11) NOT NULL,
  PRIMARY KEY (`id_article`,`id_tag`),
  KEY `id_tag` (`id_tag`),
  CONSTRAINT `article_tag_ibfk_3` FOREIGN KEY (`id_article`) REFERENCES `article` (`id`) ON DELETE CASCADE,
  CONSTRAINT `article_tag_ibfk_2` FOREIGN KEY (`id_tag`) REFERENCES `tag` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `article_tag` (`id_article`, `id_tag`) VALUES
(1,	1);

CREATE TABLE `article_text` (
  `id` int(11) NOT NULL,
  `title` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `content` text COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`),
  FULLTEXT KEY `title` (`title`,`content`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `article_text` (`id`, `title`, `content`) VALUES
(1,	'1001 tipů a triků pro PHP',	'');

CREATE TABLE `article_url` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `url` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `id_article` int(11) DEFAULT NULL,
  `valid` tinyint(1) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `url` (`url`),
  KEY `id_article` (`id_article`),
  CONSTRAINT `article_url_ibfk_1` FOREIGN KEY (`id_article`) REFERENCES `article` (`id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `article_url` (`id`, `url`, `id_article`, `valid`) VALUES
(1,	'1001-tipu-triku-php',	1,	1);

CREATE TABLE `article_visit` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `id_article` int(11) NOT NULL,
  `day` date NOT NULL,
  `visits` int(10) unsigned NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `id_article` (`id_article`,`day`),
  CONSTRAINT `article_visit_ibfk_1` FOREIGN KEY (`id_article`) REFERENCES `article` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `article_visit` (`id`, `id_article`, `day`, `visits`) VALUES
(1,	1,	'2010-06-04',	2);

CREATE TABLE `basket` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `id_user` int(11) NOT NULL,
  `id_product` int(11) NOT NULL,
  `amount` int(10) unsigned NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `id_user` (`id_user`,`id_product`),
  KEY `id_product` (`id_product`),
  CONSTRAINT `basket_ibfk_1` FOREIGN KEY (`id_user`) REFERENCES `user` (`id`) ON DELETE CASCADE,
  CONSTRAINT `basket_ibfk_2` FOREIGN KEY (`id_product`) REFERENCES `product` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `basket` (`id`, `id_user`, `id_product`, `amount`) VALUES
(1,	1,	1,	2);

CREATE TABLE `category` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `category` (`id`, `name`) VALUES
(1,	'PHP');

CREATE TABLE `comment` (
  `id` tinyint(4) NOT NULL AUTO_INCREMENT,
  `id_article` int(11) NOT NULL,
  `message` text COLLATE utf8_czech_ci NOT NULL,
  `created` datetime NOT NULL,
  `update_token` char(32) COLLATE utf8_czech_ci NOT NULL,
  `delete_token` bigint(20) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `created` (`created`),
  KEY `id_article` (`id_article`),
  CONSTRAINT `comment_ibfk_1` FOREIGN KEY (`id_article`) REFERENCES `article` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


DELIMITER ;;

CREATE TRIGGER `comment_ai` AFTER INSERT ON `comment` FOR EACH ROW
UPDATE article SET modified = NOW()
WHERE id = NEW.id_article;;

CREATE TRIGGER `comment_au` AFTER UPDATE ON `comment` FOR EACH ROW
UPDATE article SET modified = NOW()
WHERE id IN (OLD.id_article, NEW.id_article);;

CREATE TRIGGER `comment_ad` AFTER DELETE ON `comment` FOR EACH ROW
UPDATE article SET modified = NOW()
WHERE id = OLD.id_article;;

DELIMITER ;

CREATE TABLE `department` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `id_boss` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `id_boss` (`id_boss`),
  CONSTRAINT `department_ibfk_1` FOREIGN KEY (`id_boss`) REFERENCES `employee` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


CREATE TABLE `employee` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `id_department` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `id_department` (`id_department`),
  CONSTRAINT `employee_ibfk_1` FOREIGN KEY (`id_department`) REFERENCES `department` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


CREATE TABLE `import` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `remote_id` int(11) NOT NULL,
  `data` text COLLATE utf8_czech_ci NOT NULL,
  `imported` datetime NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `remote_id` (`remote_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


CREATE TABLE `login_attempts` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `login` varchar(50) CHARACTER SET utf8 NOT NULL,
  `submitted` datetime NOT NULL,
  PRIMARY KEY (`id`),
  KEY `login` (`login`),
  CONSTRAINT `login_attempts_ibfk_1` FOREIGN KEY (`login`) REFERENCES `user` (`login`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


CREATE TABLE `opening` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `day` enum('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday') CHARACTER SET utf8 NOT NULL,
  `since` time NOT NULL,
  `till` time NOT NULL,
  PRIMARY KEY (`id`),
  KEY `day` (`day`,`since`,`till`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `opening` (`id`, `day`, `since`, `till`) VALUES
(1,	'Monday',	'09:00:00',	'18:00:00'),
(2,	'Tuesday',	'09:00:00',	'18:00:00'),
(3,	'Wednesday',	'09:00:00',	'18:00:00'),
(4,	'Thursday',	'09:00:00',	'18:00:00'),
(5,	'Friday',	'09:00:00',	'18:00:00');

CREATE TABLE `page` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `url` varchar(250) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
  `expires` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `etag` varchar(250) CHARACTER SET ascii COLLATE ascii_bin DEFAULT NULL,
  `page` mediumtext COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `url` (`url`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


CREATE TABLE `param` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  `type` enum('string','number','bool') COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `param` (`id`, `name`, `type`) VALUES
(1,	'vazba',	'string');

CREATE TABLE `param_value` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `id_param` int(11) NOT NULL,
  `string` text COLLATE utf8_czech_ci,
  `number` decimal(8,2) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `id_param` (`id_param`),
  CONSTRAINT `param_value_ibfk_1` FOREIGN KEY (`id_param`) REFERENCES `param` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `param_value` (`id`, `id_param`, `string`, `number`) VALUES
(1,	1,	'brožovaná',	NULL),
(2,	1,	'pevná',	NULL);

CREATE TABLE `payment` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `code` int(11) NOT NULL,
  `amount` decimal(9,2) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `code` (`code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


CREATE TABLE `picture` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `type` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  `content` mediumblob NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


CREATE TABLE `poll` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `question` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `poll` (`id`, `question`) VALUES
(1,	'Jaký je váš oblíbený programovací jazyk?');

CREATE TABLE `poll_answer` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `id_poll` int(11) NOT NULL,
  `rank` tinyint(3) unsigned NOT NULL,
  `answer` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `votes` int(10) unsigned NOT NULL,
  PRIMARY KEY (`id`),
  KEY `id_poll` (`id_poll`,`rank`),
  CONSTRAINT `poll_answer_ibfk_1` FOREIGN KEY (`id_poll`) REFERENCES `poll` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `poll_answer` (`id`, `id_poll`, `rank`, `answer`, `votes`) VALUES
(1,	1,	1,	'PHP',	0),
(2,	1,	2,	'Python',	0);

CREATE TABLE `poll_vote` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `id_answer` int(11) NOT NULL,
  `ip` varchar(39) COLLATE utf8_czech_ci NOT NULL,
  `voted` datetime NOT NULL,
  `token` bigint(20) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `id_answer` (`id_answer`),
  CONSTRAINT `poll_vote_ibfk_1` FOREIGN KEY (`id_answer`) REFERENCES `poll_answer` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


DELIMITER ;;

CREATE TRIGGER `poll_vote_ai` AFTER INSERT ON `poll_vote` FOR EACH ROW
UPDATE poll_answer SET votes = votes + 1 WHERE id = NEW.id_answer;;

CREATE TRIGGER `poll_vote_au` AFTER UPDATE ON `poll_vote` FOR EACH ROW
UPDATE poll_answer
SET votes = votes + IF(id = OLD.id_answer, -1, 1)
WHERE id IN (OLD.id_answer, NEW.id_answer)
AND OLD.id_answer != NEW.id_answer;;

CREATE TRIGGER `poll_vote_ad` AFTER DELETE ON `poll_vote` FOR EACH ROW
UPDATE poll_answer SET votes = votes - 1 WHERE id = OLD.id_answer;;

DELIMITER ;

CREATE TABLE `pricelist` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `valid_since` date NOT NULL,
  `valid_till` date DEFAULT NULL,
  `price` decimal(9,2) unsigned NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `valid_since` (`valid_since`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `pricelist` (`id`, `valid_since`, `valid_till`, `price`) VALUES
(1,	'2010-05-10',	'2010-05-20',	10.00),
(2,	'2010-05-20',	'2010-05-30',	20.00);

CREATE TABLE `product` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  `description` text COLLATE utf8_czech_ci NOT NULL,
  `image` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `delivery` date NOT NULL,
  `price` decimal(9,2) NOT NULL,
  `vat` tinyint(3) unsigned NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `product` (`id`, `name`, `description`, `image`, `delivery`, `price`, `vat`) VALUES
(1,	'Kniha 1001 tipů a triků pro PHP',	'Autor: Jakub Vrána',	'',	'2010-09-01',	499.00,	20);

CREATE TABLE `product_param` (
  `id_product` int(11) NOT NULL,
  `id_param_value` int(11) NOT NULL,
  PRIMARY KEY (`id_product`,`id_param_value`),
  KEY `id_param_value` (`id_param_value`),
  CONSTRAINT `product_param_ibfk_1` FOREIGN KEY (`id_product`) REFERENCES `product` (`id`) ON DELETE CASCADE,
  CONSTRAINT `product_param_ibfk_2` FOREIGN KEY (`id_param_value`) REFERENCES `param_value` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `product_param` (`id_product`, `id_param_value`) VALUES
(1,	2);

CREATE TABLE `queue` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `id_xml` int(11) NOT NULL,
  `created` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `id_xml` (`id_xml`),
  CONSTRAINT `queue_ibfk_1` FOREIGN KEY (`id_xml`) REFERENCES `xml` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;


CREATE TABLE `tag` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `tag` varchar(30) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `tag` (`tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `tag` (`id`, `tag`) VALUES
(2,	'MySQL'),
(1,	'PHP');

CREATE TABLE `translation` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `lang` char(2) COLLATE utf8_czech_ci NOT NULL,
  `idf` varchar(250) COLLATE utf8_czech_ci NOT NULL,
  `translation` text COLLATE utf8_czech_ci,
  PRIMARY KEY (`id`),
  UNIQUE KEY `lang` (`lang`,`idf`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `translation` (`id`, `lang`, `idf`, `translation`) VALUES
(1,	'cs',	'translation',	'překlad');

CREATE TABLE `user` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `login` varchar(50) CHARACTER SET utf8 NOT NULL,
  `password_hmac` char(64) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
  `password_md5` char(32) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
  `password_salt` bigint(20) NOT NULL,
  `password_token` char(32) CHARACTER SET ascii COLLATE ascii_bin DEFAULT NULL,
  `password_token_generated` datetime DEFAULT NULL,
  `name` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  `email` varchar(100) COLLATE utf8_czech_ci NOT NULL,
  `email_confirm` char(32) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
  `email_valid` tinyint(1) NOT NULL,
  `email_sent` tinyint(1) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `login` (`login`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `user` (`id`, `login`, `password_hmac`, `password_md5`, `password_salt`, `password_token`, `password_token_generated`, `name`, `email`, `email_confirm`, `email_valid`, `email_sent`) VALUES
(1,	'vrana',	'f5a0d906873aa8ea0812dea04cc0f84d392899fd81fbdd05252f538c445f32e7',	'da90a32edca636d83fa1d8bb3323b38d',	1286718943,	NULL,	NULL,	'Jakub Vrána',	'test@example.com',	'd02da991eb3f85566ccf12b22119b071',	0,	0);

CREATE TABLE `user_agent` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `user_agent` varchar(250) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `user_agent` (`user_agent`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `user_agent` (`id`, `user_agent`) VALUES
(1,	'Mozilla/5.0 (Windows; U; Windows NT 5.1; cs; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3 ( .NET CLR 3.5.30729) FirePHP/0.4');

CREATE TABLE `xml` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `filename` varchar(50) COLLATE utf8_czech_ci NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;

INSERT INTO `xml` (`id`, `filename`) VALUES
(1,	'http://php.vrana.cz/atom.php');

DELIMITER ;;

CREATE TRIGGER `xml_ai` AFTER INSERT ON `xml` FOR EACH ROW
INSERT INTO queue (id_xml, created) VALUES (NEW.id, NOW());;

DELIMITER ;

